function times = getMixingtimes(fname, fac)
% parseSparkyDecayList  
%
%  This function reads the residue numbers and intensities stored in a 
%  Sparky exponential decay fitting list.  The T1 decay and std. dev.
%  fields are ignored.
%
%  Synopsis:
%     [labels, times, heights] = parseSparkyDecayList(fname)
%     [labels, times, heights] = parseSparkyDecayList(fname, fac)
%
%  Input:
%     fname = Name of the file to be read. (required)
%     fac   = A factor for converting the times to seconds. 
%             Default = 0.001 (milliseconds)
%
%  Output:
%     labels  = List of residue numbers, parsed from the first column
%     times   = List of mixing times, in seconds
%     heights = Matrix of peak heights (i, j). heights[i, j] corresponds
%               to the intensitiy of peak label[i] at time times[j].
%
%  We guarantee that the labels and heights will be sorted in order from
%  lowest residue to highest.
%

if nargin < 2
    fac = 0.001;
end

fh = fopen(fname, 'r');

if fh < 0
    error(['Could not open ', fname, ' for reading.']);
end

header = fgetl(fh);
times  = [];

if header < 0
    error('Cannot parse empty file.');
end

[~, header] = strtok(header); % "Assignment"
[~, header] = strtok(header); % "T-decay"
[~, header] = strtok(header); % "SD"

while true
    [tok, header] = strtok(header);
    if isempty(tok) break; end
    [~, time] = strtok(tok, '/');
    times = cat(2, times, str2double(time(2:end))*fac);
end








